<?php
/*
  $Id: info_shopping_cart.php,v 1.3 2006/07/16 05:09:33 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/

  require("includes/application_top.php");

  $navigation->remove_current_page();

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_INFO_SHOPPING_CART);
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="info_shopping_cart.css" media="screen,print" />
</head>
<body>
<div id="infoShoppingCart">
<h2><?php echo HEADING_TITLE; ?></h2>
<h3><?php echo SUB_HEADING_TITLE_1; ?></h3>
<p><?php echo SUB_HEADING_TEXT_1; ?></p>
<h3><?php echo SUB_HEADING_TITLE_2; ?></h3>
<p><?php echo SUB_HEADING_TEXT_2; ?></p>
<h3><?php echo SUB_HEADING_TITLE_3; ?></h3>
<p><?php echo SUB_HEADING_TEXT_3; ?></p>
<p align="right"><a href="javascript:window.close();"><?php echo TEXT_CLOSE_WINDOW; ?></a></p>
</div>
</body>
</html>
<?php
  require("includes/counter.php");
  require(DIR_WS_INCLUDES . 'application_bottom.php');
?>
